# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_sma.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/tick_analytics/v1/tick_sma.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\x82\x04\n\x0eTickSmaRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\x12L\n\x05\x66ield\x18\x03 \x01(\x0e\x32\x36.systemathics.apis.services.tick_analytics.v1.SmaPriceR\x05\x66ield\x12\x16\n\x06length\x18\x04 \x01(\x05R\x06length\x12\x31\n\x06period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06period\x12\x31\n\x06offset\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06offset\x12\x35\n\x08sampling\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08sampling\x12\x1e\n\nadjustment\x18\x08 \x01(\x08R\nadjustment\x12\x16\n\x06\x61\x63\x63\x65pt\x18\t \x03(\tR\x06\x61\x63\x63\x65pt\x12\x16\n\x06reject\x18\n \x03(\tR\x06reject\"\x9a\x01\n\x0fTickSmaResponse\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x36\n\x07\x61verage\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x07\x61verage*`\n\x08SmaPrice\x12\x19\n\x15SMA_PRICE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSMA_PRICE_TRADE\x10\x01\x12\x11\n\rSMA_PRICE_BID\x10\x02\x12\x11\n\rSMA_PRICE_ASK\x10\x03\x32\xbb\x01\n\x0eTickSmaService\x12\xa8\x01\n\x07TickSma\x12<.systemathics.apis.services.tick_analytics.v1.TickSmaRequest\x1a=.systemathics.apis.services.tick_analytics.v1.TickSmaResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/tick-analytics/sma0\x01\x42\x91\x02\n0com.systemathics.apis.services.tick_analytics.v1B\x0cTickSmaProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V1\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v1.tick_sma_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v1B\014TickSmaProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V1\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V1\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V1'
  _globals['_TICKSMASERVICE'].methods_by_name['TickSma']._options = None
  _globals['_TICKSMASERVICE'].methods_by_name['TickSma']._serialized_options = b'\202\323\344\223\002\030\022\026/v1/tick-analytics/sma'
  _globals['_SMAPRICE']._serialized_start=1013
  _globals['_SMAPRICE']._serialized_end=1109
  _globals['_TICKSMAREQUEST']._serialized_start=340
  _globals['_TICKSMAREQUEST']._serialized_end=854
  _globals['_TICKSMARESPONSE']._serialized_start=857
  _globals['_TICKSMARESPONSE']._serialized_end=1011
  _globals['_TICKSMASERVICE']._serialized_start=1112
  _globals['_TICKSMASERVICE']._serialized_end=1299
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_conditions/v1/tick_conditions.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import condition_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_condition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/tick_conditions/v1/tick_conditions.proto\x12-systemathics.apis.services.tick_conditions.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x30systemathics/apis/type/shared/v1/condition.proto\"\xa8\x01\n\x15TickConditionsRequest\x12N\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierH\x00R\nidentifier\x12\x1c\n\x08\x65xchange\x18\x02 \x01(\tH\x00R\x08\x65xchange\x12\x18\n\x06source\x18\x03 \x01(\x05H\x00R\x06sourceB\x07\n\x05value\"Y\n\x16TickConditionsResponse\x12?\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32+.systemathics.apis.type.shared.v1.ConditionR\x04\x64\x61ta2\xb7\x01\n\x15TickConditionsService\x12\x9d\x01\n\x0eTickConditions\x12\x44.systemathics.apis.services.tick_conditions.v1.TickConditionsRequest\x1a\x45.systemathics.apis.services.tick_conditions.v1.TickConditionsResponseB\x9d\x02\n1com.systemathics.apis.services.tick_conditions.v1B\x13TickConditionsProtoP\x01\xa2\x02\x04SAST\xaa\x02,Systemathics.Apis.Services.TickConditions.V1\xca\x02,Systemathics\\Apis\\Services\\TickConditions\\V1\xe2\x02\x38Systemathics\\Apis\\Services\\TickConditions\\V1\\GPBMetadata\xea\x02\x30Systemathics::Apis::Services::TickConditions::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1com.systemathics.apis.services.tick_conditions.v1B\023TickConditionsProtoP\001\242\002\004SAST\252\002,Systemathics.Apis.Services.TickConditions.V1\312\002,Systemathics\\Apis\\Services\\TickConditions\\V1\342\0028Systemathics\\Apis\\Services\\TickConditions\\V1\\GPBMetadata\352\0020Systemathics::Apis::Services::TickConditions::V1'
  _globals['_TICKCONDITIONSREQUEST']._serialized_start=220
  _globals['_TICKCONDITIONSREQUEST']._serialized_end=388
  _globals['_TICKCONDITIONSRESPONSE']._serialized_start=390
  _globals['_TICKCONDITIONSRESPONSE']._serialized_end=479
  _globals['_TICKCONDITIONSSERVICE']._serialized_start=482
  _globals['_TICKCONDITIONSSERVICE']._serialized_end=665
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/sector.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6systemathics/apis/services/static_data/v1/sector.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1cgoogle/api/annotations.proto\"b\n\rSectorRequest\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x14\n\x04\x63ode\x18\x02 \x01(\tH\x00R\x04\x63ode\x12\x16\n\x05level\x18\x03 \x01(\x05H\x00R\x05levelB\x07\n\x05value\"\x94\x01\n\x0eSectorResponse\x12J\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.SectorLevelR\x04\x64\x61ta\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x14\n\x05\x63ount\x18\x03 \x01(\x05R\x05\x63ount\"\x81\x01\n\x0bSectorLevel\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05index\x18\x02 \x01(\x05R\x05index\x12\x12\n\x04\x63ode\x18\x03 \x01(\tR\x04\x63ode\x12\x1e\n\ndefinition\x18\x04 \x01(\tR\ndefinition\x12\x14\n\x05label\x18\x05 \x01(\tR\x05label2\xae\x01\n\rSectorService\x12\x9c\x01\n\x06Sector\x12\x38.systemathics.apis.services.static_data.v1.SectorRequest\x1a\x39.systemathics.apis.services.static_data.v1.SectorResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/staticdata/sectorB\x81\x02\n-com.systemathics.apis.services.static_data.v1B\x0bSectorProtoP\x01\xa2\x02\x04SASS\xaa\x02(Systemathics.Apis.Services.StaticData.V1\xca\x02(Systemathics\\Apis\\Services\\StaticData\\V1\xe2\x02\x34Systemathics\\Apis\\Services\\StaticData\\V1\\GPBMetadata\xea\x02,Systemathics::Apis::Services::StaticData::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.sector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.systemathics.apis.services.static_data.v1B\013SectorProtoP\001\242\002\004SASS\252\002(Systemathics.Apis.Services.StaticData.V1\312\002(Systemathics\\Apis\\Services\\StaticData\\V1\342\0024Systemathics\\Apis\\Services\\StaticData\\V1\\GPBMetadata\352\002,Systemathics::Apis::Services::StaticData::V1'
  _globals['_SECTORSERVICE'].methods_by_name['Sector']._options = None
  _globals['_SECTORSERVICE'].methods_by_name['Sector']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/staticdata/sector'
  _globals['_SECTORREQUEST']._serialized_start=131
  _globals['_SECTORREQUEST']._serialized_end=229
  _globals['_SECTORRESPONSE']._serialized_start=232
  _globals['_SECTORRESPONSE']._serialized_end=380
  _globals['_SECTORLEVEL']._serialized_start=383
  _globals['_SECTORLEVEL']._serialized_end=512
  _globals['_SECTORSERVICE']._serialized_start=515
  _globals['_SECTORSERVICE']._serialized_end=689
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/mbl_market_book_updates.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import action_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2
from systemathics.apis.type.shared.v1 import side_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/type/shared/v1/mbl_market_book_updates.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a-systemathics/apis/type/shared/v1/action.proto\x1a+systemathics/apis/type/shared/v1/side.proto\"\xd2\x01\n\x14MblMarketBookUpdates\x12\x18\n\x07mapping\x18\x01 \x01(\rR\x07mapping\x12\x39\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x14\n\x05reset\x18\x03 \x01(\x08R\x05reset\x12O\n\x07updates\x18\x04 \x03(\x0b\x32\x35.systemathics.apis.type.shared.v1.MblMarketBookUpdateR\x07updates\"\x8e\x02\n\x13MblMarketBookUpdate\x12@\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32(.systemathics.apis.type.shared.v1.ActionR\x06\x61\x63tion\x12:\n\x04side\x18\x02 \x01(\x0e\x32&.systemathics.apis.type.shared.v1.SideR\x04side\x12\x14\n\x05\x64\x65pth\x18\x03 \x01(\rR\x05\x64\x65pth\x12/\n\x04size\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x04size\x12\x32\n\x05price\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05priceB\xe6\x01\n$com.systemathics.apis.type.shared.v1B\x19MblMarketBookUpdatesProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.mbl_market_book_updates_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\031MblMarketBookUpdatesProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_MBLMARKETBOOKUPDATES']._serialized_start=258
  _globals['_MBLMARKETBOOKUPDATES']._serialized_end=468
  _globals['_MBLMARKETBOOKUPDATE']._serialized_start=471
  _globals['_MBLMARKETBOOKUPDATE']._serialized_end=741
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_sma.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/daily_analytics/v1/daily_sma.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xec\x01\n\x0f\x44\x61ilySmaRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x16\n\x06length\x18\x03 \x01(\x05R\x06length\x12\x1e\n\nadjustment\x18\x04 \x01(\x08R\nadjustment\"c\n\x10\x44\x61ilySmaResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.daily_analytics.v1.DailySmaDataR\x04\x64\x61ta\"\x83\x01\n\x0c\x44\x61ilySmaData\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x36\n\x07\x61verage\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x07\x61verage2\xc0\x01\n\x0f\x44\x61ilySmaService\x12\xac\x01\n\x08\x44\x61ilySma\x12>.systemathics.apis.services.daily_analytics.v1.DailySmaRequest\x1a?.systemathics.apis.services.daily_analytics.v1.DailySmaResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/daily-analytics/smaB\x97\x02\n1com.systemathics.apis.services.daily_analytics.v1B\rDailySmaProtoP\x01\xa2\x02\x04SASD\xaa\x02,Systemathics.Apis.Services.DailyAnalytics.V1\xca\x02,Systemathics\\Apis\\Services\\DailyAnalytics\\V1\xe2\x02\x38Systemathics\\Apis\\Services\\DailyAnalytics\\V1\\GPBMetadata\xea\x02\x30Systemathics::Apis::Services::DailyAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily_analytics.v1.daily_sma_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1com.systemathics.apis.services.daily_analytics.v1B\rDailySmaProtoP\001\242\002\004SASD\252\002,Systemathics.Apis.Services.DailyAnalytics.V1\312\002,Systemathics\\Apis\\Services\\DailyAnalytics\\V1\342\0028Systemathics\\Apis\\Services\\DailyAnalytics\\V1\\GPBMetadata\352\0020Systemathics::Apis::Services::DailyAnalytics::V1'
  _globals['_DAILYSMASERVICE'].methods_by_name['DailySma']._options = None
  _globals['_DAILYSMASERVICE'].methods_by_name['DailySma']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/daily-analytics/sma'
  _globals['_DAILYSMAREQUEST']._serialized_start=304
  _globals['_DAILYSMAREQUEST']._serialized_end=540
  _globals['_DAILYSMARESPONSE']._serialized_start=542
  _globals['_DAILYSMARESPONSE']._serialized_end=641
  _globals['_DAILYSMADATA']._serialized_start=644
  _globals['_DAILYSMADATA']._serialized_end=775
  _globals['_DAILYSMASERVICE']._serialized_start=778
  _globals['_DAILYSMASERVICE']._serialized_end=970
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_raw.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_and_level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__and__level__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import raw_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_raw__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/services/tick/v1/tick_raw.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a;systemathics/apis/type/shared/v1/identifier_and_level.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a*systemathics/apis/type/shared/v1/raw.proto\"\xb9\x01\n\x0eTickRawRequest\x12V\n\x0bidentifiers\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.type.shared.v1.IdentifierAndLevelR\x0bidentifiers\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\"\x9b\x01\n\x0fTickRawResponse\x12\x39\n\x03raw\x18\x01 \x01(\x0b\x32%.systemathics.apis.type.shared.v1.RawH\x00R\x03raw\x12\x42\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00R\x07mappingB\t\n\x07payload2\x9d\x01\n\x0eTickRawService\x12\x8a\x01\n\x07TickRaw\x12\x32.systemathics.apis.services.tick.v1.TickRawRequest\x1a\x33.systemathics.apis.services.tick.v1.TickRawResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/tick/raw0\x01\x42\xe3\x01\n&com.systemathics.apis.services.tick.v1B\x0cTickRawProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V1\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V1\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V1\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v1.tick_raw_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v1B\014TickRawProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V1\312\002\"Systemathics\\Apis\\Services\\Tick\\V1\342\002.Systemathics\\Apis\\Services\\Tick\\V1\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V1'
  _globals['_TICKRAWSERVICE'].methods_by_name['TickRaw']._options = None
  _globals['_TICKRAWSERVICE'].methods_by_name['TickRaw']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/tick/raw'
  _globals['_TICKRAWREQUEST']._serialized_start=322
  _globals['_TICKRAWREQUEST']._serialized_end=507
  _globals['_TICKRAWRESPONSE']._serialized_start=510
  _globals['_TICKRAWRESPONSE']._serialized_end=665
  _globals['_TICKRAWSERVICE']._serialized_start=668
  _globals['_TICKRAWSERVICE']._serialized_end=825
# @@protoc_insertion_point(module_scope)



"""Systemathics Ganymede API Token Helpers

This module helps to create channels to access Systemathics Ganymede authenticated API.

functions:
    * get_grpc_channel - Get a channel suitable to call Ganymede gRPC API.
    * get_aio_grpc_channel - Get an aio channel suitable to call Ganymede gRPC API.
"""

import os
import grpc
import urllib.request
import pathlib
    
DEFAULT_ENDPOINT = "https://grpc.ganymede.cloud"

def get_grpc_channel(endpoint = "") -> grpc.Channel:
    """
    Get a channel suitable to call Ganymede gRPC API.
    If no endpoint parameter is given, try to use GRPC_APIS environment variable or fallback to DEFAULT_ENDPOINT.
    Note:
        For secure channels, we'll try to guess the path of CA certificates chain automatically, or download one from Mozilla official site.
        In the event CA certificates cannot be found, or if you want to use a custom file, set the SSL_CERT_FILE environment variable.
    Returns:
        A channel suitable to call Ganymede gRPC API.
    """
    endpoint = endpoint if endpoint else os.getenv('GRPC_APIS','')
    endpoint = endpoint if endpoint else DEFAULT_ENDPOINT # if no endpoint was provided, use the default one
    endpoint = endpoint if endpoint.startswith("http") else f"https://{endpoint}" # if no scheme was provided, assume it's https
    return _get_grpc_channel(endpoint)
    
def _get_grpc_channel(endpoint: str) -> grpc.Channel:
    if not endpoint or not endpoint.startswith("http"):
        raise "endpoint should have scheme http or https"
    if (endpoint.startswith("https")):
        return grpc.secure_channel(endpoint.replace("https://",""), _get_channel_credentials())
    else:
        return grpc.insecure_channel(endpoint.replace("http://",""))

def get_aio_grpc_channel(endpoint = "") -> grpc.aio.Channel:
    """
    Get an aio channel suitable to call Ganymede gRPC API.
    If no endpoint parameter is given, try to use GRPC_APIS environment variable or fallback to DEFAULT_ENDPOINT.
    Note:
        For secure channels, we'll try to guess the path of CA certificates chain automatically, or download one from Mozilla official site.
        In the event CA certificates cannot be found, or if you want to use a custom file, set the SSL_CERT_FILE environment variable.
    Returns:
        An aio channel suitable to call Ganymede gRPC API.
    """
    endpoint = endpoint if endpoint else os.getenv('GRPC_APIS','')
    endpoint = endpoint if endpoint else DEFAULT_ENDPOINT # if no endpoint was provided, use the default one
    endpoint = endpoint if endpoint.startswith("http") else f"https://{endpoint}" # if no scheme was provided, assume it's https
    return _get_aio_grpc_channel(endpoint)

def _get_aio_grpc_channel(endpoint: str) -> grpc.aio.Channel:
    if not endpoint or not endpoint.startswith("http"):
        raise "endpoint should have scheme http or https"
    if (endpoint.startswith("https")):
        return grpc.aio.secure_channel(endpoint.replace("https://",""), _get_channel_credentials())
    else:
        return grpc.aio.insecure_channel(endpoint.replace("http://",""))

def _get_channel_credentials() -> grpc.ChannelCredentials:
    # If we have a SSL_CERT_FILE env variable, use it
    ssl_cert_file = os.getenv('SSL_CERT_FILE','')
    if (ssl_cert_file !='' ):
        if (not(os.path.isfile(ssl_cert_file))):
            print(f"warn: Found SSL_CERT_FILE={ssl_cert_file} environment variable, but file doesn't exist!")
        cabundle = ssl_cert_file
    # Otherwise try autodetection
    else:
        cabundle = _autodetect_ca_bundle()

    with open(cabundle, 'rb') as f:
        credentials = grpc.ssl_channel_credentials(f.read())
        return credentials

def _get_current_mozilla_cacert() -> str:
    # up to date CA bundle (the official one embedded in Mozilla)
    url = "http://curl.haxx.se/ca/cacert.pem"
    
    # local path for CA bundle
    cadir = os.path.join(str(pathlib.Path.home()), ".systemathics")
    cafile = os.path.join(cadir, "cacert.pem")
    if not os.path.exists(cadir):
        os.makedirs(cadir)
    
    # don't redownload
    if os.path.exists(cafile):
        return cafile
    
    try:
        with urllib.request.urlopen(url) as input:
            with open(cafile, 'wb') as output:
                output.write(input.read())
    except urllib.error.URLError as e:
        print(f"Could not get {url}: {e.reason}")
           
    return cafile

def _autodetect_ca_bundle() -> str:
    cabundles = [
	"/etc/ssl/certs/ca-certificates.crt",                                  # Debian/Ubuntu/Gentoo/etc..
	"/etc/pki/tls/certs/ca-bundle.crt",                                    # Fedora/RHEL 6
	"/etc/ssl/ca-bundle.pem",                                              # OpenSUSE
	"/etc/pki/tls/cacert.pem",                                             # OpenELEC
	"/etc/pki/ca-trust/extracted/pem/tls-ca-bundle.pem",                   # CentOS/RHEL 7
	"/etc/ssl/cert.pem",                                                   # Alpine Linux
    os.path.join(os.getenv('LOCALAPPDATA',''), '.certifi', 'cacert.pem')   # Windows (for those who installed python-certifi-win32, now defunct, e.i: pip install wheel python-certifi-win32)
    ]

    # probe
    for cabundle in cabundles:
        if (os.path.isfile(cabundle)):
            print(f"Using CA bundle {cabundle}")
            return cabundle

    # fallback to current mozilla trusted root CA certificate chain
    cabundle = _get_current_mozilla_cacert()
    print(f"Using CA bundle {cabundle}")
    return cabundle



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_trades_and_book.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_and_level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__and__level__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__updates__pb2
from systemathics.apis.type.shared.v1 import trade_and_book_data_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__and__book__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/tick/v1/tick_trades_and_book.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a;systemathics/apis/type/shared/v1/identifier_and_level.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a\x33systemathics/apis/type/shared/v1/book_updates.proto\x1a:systemathics/apis/type/shared/v1/trade_and_book_data.proto\"\x93\x03\n\x18TickTradesAndBookRequest\x12V\n\x0bidentifiers\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.type.shared.v1.IdentifierAndLevelR\x0bidentifiers\x12P\n\x0c\x62ook_updates\x18\x02 \x01(\x0e\x32-.systemathics.apis.type.shared.v1.BookUpdatesR\x0b\x62ookUpdates\x12O\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\x12\x1e\n\nadjustment\x18\x04 \x01(\x08R\nadjustment\x12\x38\n\tmax_depth\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x08maxDepth\x12\"\n\x0c\x63ontributors\x18\x06 \x01(\x08R\x0c\x63ontributors\"\xb4\x01\n\x19TickTradesAndBookResponse\x12H\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x32.systemathics.apis.type.shared.v1.TradeAndBookDataH\x00R\x04\x64\x61ta\x12\x42\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00R\x07mappingB\t\n\x07payload2\xd1\x01\n\x18TickTradesAndBookService\x12\xb4\x01\n\x11TickTradesAndBook\x12<.systemathics.apis.services.tick.v1.TickTradesAndBookRequest\x1a=.systemathics.apis.services.tick.v1.TickTradesAndBookResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/tick/trades-and-book0\x01\x42\xed\x01\n&com.systemathics.apis.services.tick.v1B\x16TickTradesAndBookProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V1\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V1\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V1\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v1.tick_trades_and_book_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v1B\026TickTradesAndBookProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V1\312\002\"Systemathics\\Apis\\Services\\Tick\\V1\342\002.Systemathics\\Apis\\Services\\Tick\\V1\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V1'
  _globals['_TICKTRADESANDBOOKSERVICE'].methods_by_name['TickTradesAndBook']._options = None
  _globals['_TICKTRADESANDBOOKSERVICE'].methods_by_name['TickTradesAndBook']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/tick/trades-and-book'
  _globals['_TICKTRADESANDBOOKREQUEST']._serialized_start=435
  _globals['_TICKTRADESANDBOOKREQUEST']._serialized_end=838
  _globals['_TICKTRADESANDBOOKRESPONSE']._serialized_start=841
  _globals['_TICKTRADESANDBOOKRESPONSE']._serialized_end=1021
  _globals['_TICKTRADESANDBOOKSERVICE']._serialized_start=1024
  _globals['_TICKTRADESANDBOOKSERVICE']._serialized_end=1233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/mappings.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import memo_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_memo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/systemathics/apis/type/shared/v1/mappings.proto\x12 systemathics.apis.type.shared.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/memo.proto\"\xb6\x01\n\x07Mapping\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12:\n\x04memo\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.MemoR\x04memo\x12!\n\x0c\x65vent_source\x18\x03 \x01(\rR\x0b\x65ventSource\"K\n\x08Mappings\x12?\n\x05table\x18\x01 \x03(\x0b\x32).systemathics.apis.type.shared.v1.MappingR\x05tableB\xda\x01\n$com.systemathics.apis.type.shared.v1B\rMappingsProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.mappings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\rMappingsProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_MAPPING']._serialized_start=182
  _globals['_MAPPING']._serialized_end=364
  _globals['_MAPPINGS']._serialized_start=366
  _globals['_MAPPINGS']._serialized_end=441
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_quotes.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import quotes_data_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_quotes__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/services/tick/v1/tick_quotes.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a\x32systemathics/apis/type/shared/v1/quotes_data.proto\"\xd4\x01\n\x11TickQuotesRequest\x12N\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\x0bidentifiers\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\x12\x1e\n\nadjustment\x18\x03 \x01(\x08R\nadjustment\"\xa7\x01\n\x12TickQuotesResponse\x12\x42\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.QuotesDataH\x00R\x04\x64\x61ta\x12\x42\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00R\x07mappingB\t\n\x07payload2\xac\x01\n\x11TickQuotesService\x12\x96\x01\n\nTickQuotes\x12\x35.systemathics.apis.services.tick.v1.TickQuotesRequest\x1a\x36.systemathics.apis.services.tick.v1.TickQuotesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/tick/quotes0\x01\x42\xe6\x01\n&com.systemathics.apis.services.tick.v1B\x0fTickQuotesProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V1\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V1\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V1\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v1.tick_quotes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v1B\017TickQuotesProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V1\312\002\"Systemathics\\Apis\\Services\\Tick\\V1\342\002.Systemathics\\Apis\\Services\\Tick\\V1\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V1'
  _globals['_TICKQUOTESSERVICE'].methods_by_name['TickQuotes']._options = None
  _globals['_TICKQUOTESSERVICE'].methods_by_name['TickQuotes']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/tick/quotes'
  _globals['_TICKQUOTESREQUEST']._serialized_start=323
  _globals['_TICKQUOTESREQUEST']._serialized_end=535
  _globals['_TICKQUOTESRESPONSE']._serialized_start=538
  _globals['_TICKQUOTESRESPONSE']._serialized_end=705
  _globals['_TICKQUOTESSERVICE']._serialized_start=708
  _globals['_TICKQUOTESSERVICE']._serialized_end=880
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_priips_batch.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.services.tick_analytics.v1 import tick_priips_pb2 as systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v1_dot_tick__priips__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDsystemathics/apis/services/tick_analytics/v1/tick_priips_batch.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a>systemathics/apis/services/tick_analytics/v1/tick_priips.proto\"\xe9\x02\n\x16TickPriipsBatchRequest\x12\x15\n\x06\x63sv_gz\x18\x01 \x01(\x0cR\x05\x63svGz\x12O\n\x05\x66ield\x18\x02 \x01(\x0e\x32\x39.systemathics.apis.services.tick_analytics.v1.PriipsPriceR\x05\x66ield\x12\x33\n\x07latency\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07latency\x12\x16\n\x06\x61\x63\x63\x65pt\x18\x04 \x03(\tR\x06\x61\x63\x63\x65pt\x12\x16\n\x06reject\x18\x05 \x03(\tR\x06reject\x12\x18\n\x07metrics\x18\x06 \x01(\x08R\x07metrics\x12K\n\"use_reverse_iteration_optimization\x18\x07 \x01(\x08R\x1fuseReverseIterationOptimization\x12\x1b\n\ttime_zone\x18\x08 \x01(\x0cR\x08timeZone\"T\n\x17TickPriipsBatchResponse\x12\x15\n\x06\x63sv_gz\x18\x01 \x01(\x0cR\x05\x63svGz\x12\"\n\rerrors_csv_gz\x18\x02 \x01(\x0cR\x0b\x65rrorsCsvGz2\xe2\x01\n\x16TickPriipsBatchService\x12\xc7\x01\n\x0fTickPriipsBatch\x12\x44.systemathics.apis.services.tick_analytics.v1.TickPriipsBatchRequest\x1a\x45.systemathics.apis.services.tick_analytics.v1.TickPriipsBatchResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/tick-analytics/priips-batchB\x99\x02\n0com.systemathics.apis.services.tick_analytics.v1B\x14TickPriipsBatchProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V1\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v1.tick_priips_batch_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v1B\024TickPriipsBatchProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V1\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V1\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V1'
  _globals['_TICKPRIIPSBATCHSERVICE'].methods_by_name['TickPriipsBatch']._options = None
  _globals['_TICKPRIIPSBATCHSERVICE'].methods_by_name['TickPriipsBatch']._serialized_options = b'\202\323\344\223\002!\022\037/v1/tick-analytics/priips-batch'
  _globals['_TICKPRIIPSBATCHREQUEST']._serialized_start=245
  _globals['_TICKPRIIPSBATCHREQUEST']._serialized_end=606
  _globals['_TICKPRIIPSBATCHRESPONSE']._serialized_start=608
  _globals['_TICKPRIIPSBATCHRESPONSE']._serialized_end=692
  _globals['_TICKPRIIPSBATCHSERVICE']._serialized_start=695
  _globals['_TICKPRIIPSBATCHSERVICE']._serialized_end=921
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/dividends.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?systemathics/apis/services/corporate_actions/v1/dividends.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xb5\x01\n\x10\x44ividendsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\"b\n\x11\x44ividendsResponse\x12M\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x39.systemathics.apis.services.corporate_actions.v1.DividendR\x04\x64\x61ta\"\xb2\x01\n\x08\x44ividend\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12Q\n\x04type\x18\x02 \x01(\x0e\x32=.systemathics.apis.services.corporate_actions.v1.DividendTypeR\x04type\x12\x16\n\x06\x61mount\x18\x03 \x01(\x01R\x06\x61mount\x12\x14\n\x05score\x18\x04 \x01(\x01R\x05score*^\n\x0c\x44ividendType\x12\x1d\n\x19\x44IVIDEND_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x44IVIDEND_TYPE_CASH\x10\x01\x12\x17\n\x13\x44IVIDEND_TYPE_STOCK\x10\x02\x32\xd0\x01\n\x10\x44ividendsService\x12\xbb\x01\n\tDividends\x12\x41.systemathics.apis.services.corporate_actions.v1.DividendsRequest\x1a\x42.systemathics.apis.services.corporate_actions.v1.DividendsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/corporate-actions/dividendsB\xa2\x02\n3com.systemathics.apis.services.corporate_actions.v1B\x0e\x44ividendsProtoP\x01\xa2\x02\x04SASC\xaa\x02.Systemathics.Apis.Services.CorporateActions.V1\xca\x02.Systemathics\\Apis\\Services\\CorporateActions\\V1\xe2\x02:Systemathics\\Apis\\Services\\CorporateActions\\V1\\GPBMetadata\xea\x02\x32Systemathics::Apis::Services::CorporateActions::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.corporate_actions.v1.dividends_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3com.systemathics.apis.services.corporate_actions.v1B\016DividendsProtoP\001\242\002\004SASC\252\002.Systemathics.Apis.Services.CorporateActions.V1\312\002.Systemathics\\Apis\\Services\\CorporateActions\\V1\342\002:Systemathics\\Apis\\Services\\CorporateActions\\V1\\GPBMetadata\352\0022Systemathics::Apis::Services::CorporateActions::V1'
  _globals['_DIVIDENDSSERVICE'].methods_by_name['Dividends']._options = None
  _globals['_DIVIDENDSSERVICE'].methods_by_name['Dividends']._serialized_options = b'\202\323\344\223\002!\022\037/v1/corporate-actions/dividends'
  _globals['_DIVIDENDTYPE']._serialized_start=740
  _globals['_DIVIDENDTYPE']._serialized_end=834
  _globals['_DIVIDENDSREQUEST']._serialized_start=276
  _globals['_DIVIDENDSREQUEST']._serialized_end=457
  _globals['_DIVIDENDSRESPONSE']._serialized_start=459
  _globals['_DIVIDENDSRESPONSE']._serialized_end=557
  _globals['_DIVIDEND']._serialized_start=560
  _globals['_DIVIDEND']._serialized_end=738
  _globals['_DIVIDENDSSERVICE']._serialized_start=837
  _globals['_DIVIDENDSSERVICE']._serialized_end=1045
# @@protoc_insertion_point(module_scope)
